Installation instructions
=========================

The package is a pure python package, installation is thus very straight forward.

pypi
----

the python package is available on `pypi <https://pypi.org/project/geetools/>`__ and can be installed it using ``pip``:

.. code-block:: console

    pip install geetools

conda
-----

The python package is available on `conda <https://anaconda.org/conda-forge/geetools>`__ and can be installed using ``conda`` and the ``conda-forge`` channel:

.. code-block:: console

    conda install -c conda-forge geetools

from source
-----------

You can also install the package from source. First clone the repository:

.. code-block:: console

    git clone https://github.com/gee-community/geetools.git

Then, navigate to the folder and install the package using pip:

.. code-block:: console

    cd geetools
    pip install .

Multiple version of the package requirements are available and are specifically important for local development.
See the :doc:`contribute` page for more information.

